#include <QtGui/QMainWindow>
#include <QList>

class BaseWidget;
class DiffWidget;
class MergeWidget;
class QComboBox;

class CalamariWindow : public QMainWindow
{
    Q_OBJECT

public:
	CalamariWindow(char* file1, char* file2);
	CalamariWindow(QImage file1, QImage file2, QString title);
	CalamariWindow(char* file1, char* file2, char* file3, char* file4=0);
	CalamariWindow(QImage base, QImage theirs, QImage yours, MergeWidget* parent);
    ~CalamariWindow();

	QImage getResult();

protected:
	void closeEvent( QCloseEvent* e );

private slots:
	void nil() {};
	void setAutoSize( bool auto );
	void setZoom( int factor );

	void colorOpts();
	void saveOpts();

	void maskToggled( bool );

	void setBrushSize( bool );
	void setEraserSize( bool );

	void diffBaseTheirs();
	void diffBaseYours();

	void help();
	void about();
	void helpAlpha();

private:
	void initDiffToolbar();
	void initMergeToolbar();

	void addMaskOpts( QToolBar* t );
	void addZoomOpts( QToolBar* t );

	void loadOpts();

	BaseWidget* baseWidget;
	DiffWidget* diffWidget;
	MergeWidget* mergeWidget;

	int zoomFactor;
	QComboBox* zoomList;

	QList<QAction*> maskActions;

	int brushSize;
	int eraserSize;

	QAction* save;

	MergeWidget* rgbWidget; //only set if this is an alpha merging window
};

