#include "DiffWidget.h"
#include "util.h"

#include <QColorDialog>
#include <QLayout>
#include <QMessageBox>
#include <QPalette>
#include <QPainter>
#include <QSlider>

DiffWidget::DiffWidget( char* file1, char* file2 )
:BaseWidget( file1, file2 )
{
	//BaseWidget constructor sets up the two left projectors, the slider,
	//the scroll area, and the layouts.

	initDiffWidget();
}

DiffWidget::DiffWidget( QImage f1, QImage f2 )
:BaseWidget( f1, f2 )
{
	initDiffWidget();
}

void DiffWidget::initDiffWidget()
{
	// Draw the legs on top of an opaque background, so as to eliminate
	// their alpha channels while preserving the appearance of them.
	if ( leg1.hasAlphaChannel() )
	{
		QImage tmp1 = leg1;
		leg1.fill( p1->palette().background().color().rgb() );
		QPainter pa;
		pa.begin( &leg1 );
		pa.drawImage( QPoint(), tmp1 );
		pa.end();
	}
	if ( leg2.hasAlphaChannel() )
	{
		QImage tmp2 = leg2;
		leg2.fill( p2->palette().background().color().rgb() );
		QPainter pb;
		pb.begin( &leg2 );
		pb.drawImage( QPoint(), tmp2 );
		pb.end();
	}

	connect( slider, SIGNAL( valueChanged(int) ), this, SLOT( doBlend(int) ) );

	main = new ImageProjector;
	main_l->addWidget( main );

	diff = QImage( leg1.width(), leg1.height(), QImage::Format_ARGB32_Premultiplied );

	//Scratch image
	scratch = QImage( leg1.width(), leg1.height(), QImage::Format_ARGB32_Premultiplied );
	s_alpha = QImage( leg1.width(), leg1.height(), QImage::Format_Indexed8 );
	QVector<QRgb> colors(256);
	for ( int i = 0 ; i < 256 ; i++ )
	{
		colors[i] = qRgb( i, i, i );
	}
	s_alpha.setColorTable( colors );

	main->setImage( &diff );

	slider->setRange( 0, 255 );
	slider->setValue( 127 );
	slider->setSingleStep( 16 );
	slider->setPageStep( 255 );

	mask = QBitmap( leg1.size() );
	main->setMask( &mask );
}

DiffWidget::~DiffWidget(void)
{
}

void DiffWidget::doBlend( int eightBit )
{
	if ( diff.isNull() ) return;
	if ( eightBit == 0 )
	{
		diff = leg2;
	}
	else if ( eightBit == 255 )
	{
		diff = leg1;
	}
	else
	{
		s_alpha.fill( eightBit );
		QPainter s;
		s.begin( &scratch );
		s.drawImage( 0, 0, leg1 );
		s.end();
		scratch.setAlphaChannel( s_alpha );
		QPainter p( &diff );
		p.drawImage( 0, 0, leg2 );
		p.drawImage( 0, 0, scratch );
	}
	main->update();
}

void DiffWidget::setDiffMask( bool on )
{
	main->setMaskEnabled( on );
}

void DiffWidget::setTolerance( int dec )
{
	BaseWidget::setTolerance( dec );
	imageDiff( leg1, leg2, &mask, tolerance );
	main->update();
}
